@@ -3,12 +3,25 @@
 require "test_helper"
 
 class ActionCable::Connection::SubscriptionsTest < ActionCable::TestCase
+  class ChatChannelError < Exception; end
+
   class Connection < ActionCable::Connection::Base
-    attr_reader :websocket
+    attr_reader :websocket, :exceptions
+
+    rescue_from ChatChannelError, with: :error_handler
+
+    def initialize(*)
+      super
+      @exceptions = []
+    end
 
     def send_async(method, *args)
       send method, *args
     end
+
+    def error_handler(e)
+      @exceptions << e
+    end
   end
 
   class ChatChannel < ActionCable::Channel::Base
@@ -22,6 +35,10 @@ class ActionCable::Connection::SubscriptionsTest < ActionCable::TestCase
     def speak(data)
       @lines << data
     end
+
+    def throw_exception(_data)
+      raise ChatChannelError.new("Uh Oh")
+    end
   end
 
   setup do
@@ -85,6 +102,19 @@ class ActionCable::Connection::SubscriptionsTest < ActionCable::TestCase
     end
   end
 
+  test "accessing exceptions thrown during command execution" do
+    run_in_eventmachine do
+      setup_connection
+      subscribe_to_chat_channel
+
+      data = { "content" => "Hello World!", "action" => "throw_exception" }
+      @subscriptions.execute_command "command" => "message", "identifier" => @chat_identifier, "data" => ActiveSupport::JSON.encode(data)
+
+      exception = @connection.exceptions.first
+      assert_kind_of ChatChannelError, exception
+    end
+  end
+
   test "unsubscribe from all" do
     run_in_eventmachine do
       setup_connection
