@@ -76,13 +76,18 @@ class MessageDeliveryTest < ActiveSupport::TestCase
   end
 
   test "should enqueue a delivery with a delay" do
-    travel_to Time.new(2004, 11, 24, 01, 04, 44) do
+    travel_to Time.new(2004, 11, 24, 1, 4, 44) do
       assert_performed_with(job: ActionMailer::MailDeliveryJob, at: Time.current + 10.minutes, args: ["DelayedMailer", "test_message", "deliver_now", args: [1, 2, 3]]) do
         @mail.deliver_later wait: 10.minutes
       end
     end
   end
 
+  test "should enqueue a delivery with a priority" do
+    job = @mail.deliver_later priority: 10
+    assert_equal 10, job.priority
+  end
+
   test "should enqueue a delivery at a specific time" do
     later_time = Time.current + 1.hour
     assert_performed_with(job: ActionMailer::MailDeliveryJob, at: later_time, args: ["DelayedMailer", "test_message", "deliver_now", args: [1, 2, 3]]) do
