@@ -1,6 +1,7 @@
 # frozen_string_literal: true
 
 require "abstract_unit"
+require "test_renderable"
 
 class RendererTest < ActiveSupport::TestCase
   test "action controller base has a renderer" do
@@ -40,7 +41,7 @@ class RendererTest < ActiveSupport::TestCase
 
   test "rendering with an instance renderer" do
     renderer = ApplicationController.renderer.new
-    content  = assert_deprecated { renderer.render file: "test/hello_world" }
+    content  = renderer.render template: "test/hello_world"
 
     assert_equal "Hello world!", content
   end
@@ -65,6 +66,15 @@ class RendererTest < ActiveSupport::TestCase
     assert_equal "The secret is foo\n", content
   end
 
+  test "render a renderable object" do
+    renderer = ApplicationController.renderer
+
+    assert_equal(
+      %(Hello, World!),
+      renderer.render(TestRenderable.new)
+    )
+  end
+
   test "rendering with custom env" do
     renderer = ApplicationController.renderer.new method: "post"
     content  = renderer.render inline: "<%= request.post? %>"
@@ -99,7 +109,7 @@ class RendererTest < ActiveSupport::TestCase
     xml  = "<p>Hello world!</p>\n"
 
     assert_equal html, render["respond_to/using_defaults"]
-    assert_equal xml,  render["respond_to/using_defaults.xml.builder"]
+    assert_equal xml,  assert_deprecated { render["respond_to/using_defaults.xml.builder"] }
     assert_equal xml,  render["respond_to/using_defaults", formats: :xml]
   end
 
