@@ -5,7 +5,7 @@ require "abstract_unit"
 module TestFileUtils
   def file_name() File.basename(__FILE__) end
   def file_path() __FILE__ end
-  def file_data() @data ||= File.open(file_path, "rb") { |f| f.read } end
+  def file_data() @data ||= File.binread(file_path) end
 end
 
 class SendFileController < ActionController::Base
