@@ -18,17 +18,12 @@ module AbstractController
         "renderer/string.erb" => "With String",
         "renderer/symbol.erb" => "With Symbol",
         "string/with_path.erb" => "With String With Path",
-        "some/file.erb" => "With File"
       )]
 
       def template
         render template: "template"
       end
 
-      def file
-        ActiveSupport::Deprecation.silence { render file: "some/file" }
-      end
-
       def inline
         render inline: "With <%= :Inline %>"
       end
@@ -64,11 +59,6 @@ module AbstractController
         assert_equal "With Template", @controller.response_body
       end
 
-      def test_render_file
-        assert_equal "With File", @controller.process(:file)
-        assert_equal "With File", @controller.response_body
-      end
-
       def test_render_inline
         assert_equal "With Inline", @controller.process(:inline)
         assert_equal "With Inline", @controller.response_body
