@@ -11,16 +11,20 @@ ActionController::Base.view_paths = [ File.expand_path("../../fixtures/actionpac
 
 class LayoutTest < ActionController::Base
   def self.controller_path; "views" end
-  def self._implied_layout_name; to_s.underscore.gsub(/_controller$/, "") ; end
+  def self._implied_layout_name; to_s.underscore.delete_suffix("_controller") ; end
   self.view_paths = ActionController::Base.view_paths.dup
 end
 
 module TemplateHandlerHelper
   def with_template_handler(*extensions, handler)
     ActionView::Template.register_template_handler(*extensions, handler)
+    ActionController::Base.view_paths.paths.each(&:clear_cache)
+    ActionView::LookupContext::DetailsKey.clear
     yield
   ensure
     ActionView::Template.unregister_template_handler(*extensions)
+    ActionController::Base.view_paths.paths.each(&:clear_cache)
+    ActionView::LookupContext::DetailsKey.clear
   end
 end
 
@@ -233,10 +237,9 @@ class LayoutSetInResponseTest < ActionController::TestCase
 
   def test_absolute_pathed_layout
     @controller = AbsolutePathLayoutController.new
-    assert_deprecated do
+    assert_raises(ArgumentError) do
       get :hello
     end
-    assert_equal "layout_test.erb hello.erb", @response.body.strip
   end
 end
 
