@@ -1,9 +1,6 @@
 # frozen_string_literal: true
 
 require "active_record_unit"
-require "active_record/railties/collection_cache_association_loading"
-
-ActionView::PartialRenderer.prepend(ActiveRecord::Railties::CollectionCacheAssociationLoading)
 
 class MultifetchCacheTest < ActiveRecordTestCase
   fixtures :topics, :replies
