@@ -3,7 +3,6 @@
 module ERBTest
   class ViewContext
     include ActionView::Helpers::UrlHelper
-    include SharedTestRoutes.url_helpers
     include ActionView::Helpers::TagHelper
     include ActionView::Helpers::JavaScriptHelper
     include ActionView::Helpers::FormHelper
@@ -14,9 +13,15 @@ module ERBTest
   end
 
   class BlockTestCase < ActiveSupport::TestCase
-    def render_content(start, inside)
+    def render_content(start, inside, routes = nil)
+      routes ||= ActionDispatch::Routing::RouteSet.new.tap do |rs|
+        rs.draw { }
+      end
+      context = Class.new(ViewContext) {
+        include routes.url_helpers
+      }.new
       template = block_helper(start, inside)
-      ActionView::Template::Handlers::ERB.erb_implementation.new(template).evaluate(ViewContext.new)
+      ActionView::Template::Handlers::ERB.erb_implementation.new(template).evaluate(context)
     end
 
     def block_helper(str, rest)
