@@ -8,24 +8,36 @@ require "jobs/kwargs_job"
 require "support/stubs/strong_parameters"
 
 class ArgumentSerializationTest < ActiveSupport::TestCase
+  module ModuleArgument
+    class ClassArgument; end
+  end
+
+  class ClassArgument; end
+
   setup do
     @person = Person.find("5")
   end
 
   [ nil, 1, 1.0, 1_000_000_000_000_000_000_000,
     "a", true, false, BigDecimal(5),
-    :a, 1.day, Date.new(2001, 2, 3), Time.new(2002, 10, 31, 2, 2, 2, "+02:00"),
-    DateTime.new(2001, 2, 3, 4, 5, 6, "+03:00"),
-    ActiveSupport::TimeWithZone.new(Time.utc(1999, 12, 31, 23, 59, 59), ActiveSupport::TimeZone["UTC"]),
+    :a,
+    1.day,
+    Date.new(2001, 2, 3),
+    Time.new(2002, 10, 31, 2, 2, 2.123456789r, "+02:00"),
+    DateTime.new(2001, 2, 3, 4, 5, 6.123456r, "+03:00"),
+    ActiveSupport::TimeWithZone.new(Time.utc(1999, 12, 31, 23, 59, "59.123456789".to_r), ActiveSupport::TimeZone["UTC"]),
     [ 1, "a" ],
-    { "a" => 1 }
+    { "a" => 1 },
+    ModuleArgument,
+    ModuleArgument::ClassArgument,
+    ClassArgument
   ].each do |arg|
-    test "serializes #{arg.class} - #{arg} verbatim" do
+    test "serializes #{arg.class} - #{arg.inspect} verbatim" do
       assert_arguments_unchanged arg
     end
   end
 
-  [ Object.new, self, Person.find("5").to_gid ].each do |arg|
+  [ Object.new, Person.find("5").to_gid ].each do |arg|
     test "does not serialize #{arg.class}" do
       assert_raises ActiveJob::SerializationError do
         ActiveJob::Arguments.serialize [ arg ]
