@@ -89,7 +89,7 @@ module ActiveRecord
       # This method is useful in validations and before callbacks to determine
       # if the next call to +save+ will change a particular attribute. It can be
       # invoked as +will_save_change_to_name?+ instead of
-      # <tt>will_save_change_to_attribute("name")</tt>.
+      # <tt>will_save_change_to_attribute?("name")</tt>.
       #
       # ==== Options
       #
@@ -156,16 +156,6 @@ module ActiveRecord
       end
 
       private
-        def mutations_from_database
-          sync_with_transaction_state if @transaction_state&.finalized?
-          super
-        end
-
-        def mutations_before_last_save
-          sync_with_transaction_state if @transaction_state&.finalized?
-          super
-        end
-
         def write_attribute_without_type_cast(attr_name, value)
           result = super
           clear_attribute_change(attr_name)
