@@ -8,6 +8,36 @@ class Mysql2AdapterTest < ActiveRecord::Mysql2TestCase
 
   def setup
     @conn = ActiveRecord::Base.connection
+    @connection_handler = ActiveRecord::Base.connection_handler
+  end
+
+  def test_connection_error
+    assert_raises ActiveRecord::ConnectionNotEstablished do
+      ActiveRecord::Base.mysql2_connection(socket: File::NULL)
+    end
+  end
+
+  def test_reconnection_error
+    fake_connection = Class.new do
+      def query_options
+        {}
+      end
+
+      def query(*)
+      end
+
+      def close
+      end
+    end.new
+    @conn = ActiveRecord::ConnectionAdapters::Mysql2Adapter.new(
+      fake_connection,
+      ActiveRecord::Base.logger,
+      nil,
+      { socket: File::NULL }
+    )
+    assert_raises ActiveRecord::ConnectionNotEstablished do
+      @conn.reconnect!
+    end
   end
 
   def test_exec_query_nothing_raises_with_no_result_queries
@@ -19,6 +49,19 @@ class Mysql2AdapterTest < ActiveRecord::Mysql2TestCase
     end
   end
 
+  def test_database_exists_returns_false_if_database_does_not_exist
+    db_config = ActiveRecord::Base.configurations.configs_for(env_name: "arunit", name: "primary")
+    config = db_config.configuration_hash.merge(database: "inexistent_activerecord_unittest")
+    assert_not ActiveRecord::ConnectionAdapters::Mysql2Adapter.database_exists?(config),
+      "expected database to not exist"
+  end
+
+  def test_database_exists_returns_true_when_the_database_exists
+    db_config = ActiveRecord::Base.configurations.configs_for(env_name: "arunit", name: "primary")
+    assert ActiveRecord::ConnectionAdapters::Mysql2Adapter.database_exists?(db_config.configuration_hash),
+      "expected database #{db_config.database} to exist"
+  end
+
   def test_columns_for_distinct_zero_orders
     assert_equal "posts.id",
       @conn.columns_for_distinct("posts.id", [])
@@ -48,12 +91,13 @@ class Mysql2AdapterTest < ActiveRecord::Mysql2TestCase
   end
 
   def test_columns_for_distinct_with_arel_order
-    order = Object.new
-    def order.to_sql
-      "posts.created_at desc"
-    end
+    Arel::Table.engine = nil # should not rely on the global Arel::Table.engine
+
+    order = Arel.sql("posts.created_at").desc
     assert_equal "posts.created_at AS alias_0, posts.id",
       @conn.columns_for_distinct("posts.id", [order])
+  ensure
+    Arel::Table.engine = ActiveRecord::Base
   end
 
   def test_errors_for_bigint_fks_on_integer_pk_table_in_alter_table
@@ -64,11 +108,14 @@ class Mysql2AdapterTest < ActiveRecord::Mysql2TestCase
       @conn.add_foreign_key :engines, :old_cars
     end
 
-    assert_includes error.message, <<-MSG.squish
-      Column `old_car_id` on table `engines` does not match column `id` on `old_cars`,
-      which has type `int(11)`. To resolve this issue, change the type of the `old_car_id`
-      column on `engines` to be :integer. (For example `t.integer :old_car_id`).
-    MSG
+    assert_match(
+      %r/Column `old_car_id` on table `engines` does not match column `id` on `old_cars`, which has type `int(\(11\))?`\./,
+      error.message
+    )
+    assert_match(
+      %r/To resolve this issue, change the type of the `old_car_id` column on `engines` to be :integer\. \(For example `t.integer :old_car_id`\)\./,
+      error.message
+    )
     assert_not_nil error.cause
   ensure
     @conn.execute("ALTER TABLE engines DROP COLUMN old_car_id") rescue nil
@@ -78,7 +125,7 @@ class Mysql2AdapterTest < ActiveRecord::Mysql2TestCase
     # table old_cars has primary key of integer
 
     error = assert_raises(ActiveRecord::MismatchedForeignKey) do
-      @conn.execute(<<-SQL)
+      @conn.execute(<<~SQL)
         CREATE TABLE activerecord_unittest.foos (
           id bigint NOT NULL AUTO_INCREMENT PRIMARY KEY,
           old_car_id bigint,
@@ -88,11 +135,14 @@ class Mysql2AdapterTest < ActiveRecord::Mysql2TestCase
       SQL
     end
 
-    assert_includes error.message, <<-MSG.squish
-      Column `old_car_id` on table `foos` does not match column `id` on `old_cars`,
-      which has type `int(11)`. To resolve this issue, change the type of the `old_car_id`
-      column on `foos` to be :integer. (For example `t.integer :old_car_id`).
-    MSG
+    assert_match(
+      %r/Column `old_car_id` on table `foos` does not match column `id` on `old_cars`, which has type `int(\(11\))?`\./,
+      error.message
+    )
+    assert_match(
+      %r/To resolve this issue, change the type of the `old_car_id` column on `foos` to be :integer\. \(For example `t.integer :old_car_id`\)\./,
+      error.message
+    )
     assert_not_nil error.cause
   ensure
     @conn.drop_table :foos, if_exists: true
@@ -102,7 +152,7 @@ class Mysql2AdapterTest < ActiveRecord::Mysql2TestCase
     # table old_cars has primary key of bigint
 
     error = assert_raises(ActiveRecord::MismatchedForeignKey) do
-      @conn.execute(<<-SQL)
+      @conn.execute(<<~SQL)
         CREATE TABLE activerecord_unittest.foos (
           id bigint NOT NULL AUTO_INCREMENT PRIMARY KEY,
           car_id int,
@@ -112,11 +162,14 @@ class Mysql2AdapterTest < ActiveRecord::Mysql2TestCase
       SQL
     end
 
-    assert_includes error.message, <<-MSG.squish
-      Column `car_id` on table `foos` does not match column `id` on `cars`,
-      which has type `bigint(20)`. To resolve this issue, change the type of the `car_id`
-      column on `foos` to be :bigint. (For example `t.bigint :car_id`).
-    MSG
+    assert_match(
+      %r/Column `car_id` on table `foos` does not match column `id` on `cars`, which has type `bigint(\(20\))?`\./,
+      error.message
+    )
+    assert_match(
+      %r/To resolve this issue, change the type of the `car_id` column on `foos` to be :bigint\. \(For example `t.bigint :car_id`\)\./,
+      error.message
+    )
     assert_not_nil error.cause
   ensure
     @conn.drop_table :foos, if_exists: true
@@ -126,7 +179,7 @@ class Mysql2AdapterTest < ActiveRecord::Mysql2TestCase
     # table old_cars has primary key of string
 
     error = assert_raises(ActiveRecord::MismatchedForeignKey) do
-      @conn.execute(<<-SQL)
+      @conn.execute(<<~SQL)
         CREATE TABLE activerecord_unittest.foos (
           id bigint NOT NULL AUTO_INCREMENT PRIMARY KEY,
           subscriber_id bigint,
@@ -136,7 +189,7 @@ class Mysql2AdapterTest < ActiveRecord::Mysql2TestCase
       SQL
     end
 
-    assert_includes error.message, <<-MSG.squish
+    assert_includes error.message, <<~MSG.squish
       Column `subscriber_id` on table `foos` does not match column `nick` on `subscribers`,
       which has type `varchar(255)`. To resolve this issue, change the type of the `subscriber_id`
       column on `foos` to be :string. (For example `t.string :subscriber_id`).
@@ -146,8 +199,39 @@ class Mysql2AdapterTest < ActiveRecord::Mysql2TestCase
     @conn.drop_table :foos, if_exists: true
   end
 
-  private
+  def test_read_timeout_exception
+    db_config = ActiveRecord::Base.configurations.configs_for(env_name: "arunit", name: "primary")
 
+    ActiveRecord::Base.establish_connection(
+      db_config.configuration_hash.merge("read_timeout" => 1)
+    )
+
+    error = assert_raises(ActiveRecord::AdapterTimeout) do
+      ActiveRecord::Base.connection.execute("SELECT SLEEP(2)")
+    end
+    assert_kind_of ActiveRecord::QueryAborted, error
+
+    assert_equal Mysql2::Error::TimeoutError, error.cause.class
+  ensure
+    ActiveRecord::Base.establish_connection :arunit
+  end
+
+  def test_statement_timeout_error_codes
+    raw_conn = @conn.raw_connection
+    assert_raises(ActiveRecord::StatementTimeout) do
+      raw_conn.stub(:query, ->(_sql) { raise Mysql2::Error.new("fail", 50700, ActiveRecord::ConnectionAdapters::AbstractMysqlAdapter::ER_FILSORT_ABORT) }) {
+        @conn.execute("SELECT 1")
+      }
+    end
+
+    assert_raises(ActiveRecord::StatementTimeout) do
+      raw_conn.stub(:query, ->(_sql) { raise Mysql2::Error.new("fail", 50700, ActiveRecord::ConnectionAdapters::AbstractMysqlAdapter::ER_QUERY_TIMEOUT) }) {
+        @conn.execute("SELECT 1")
+      }
+    end
+  end
+
+  private
     def with_example_table(definition = "id int auto_increment primary key, number int, data varchar(255)", &block)
       super(@conn, "ex", definition, &block)
     end
