@@ -26,19 +26,19 @@ module ActiveRecord
     end
 
     def test_encoding
-      assert_queries(1) do
+      assert_queries(1, ignore_none: true) do
         assert_not_nil @connection.encoding
       end
     end
 
     def test_collation
-      assert_queries(1) do
+      assert_queries(1, ignore_none: true) do
         assert_not_nil @connection.collation
       end
     end
 
     def test_ctype
-      assert_queries(1) do
+      assert_queries(1, ignore_none: true) do
         assert_not_nil @connection.ctype
       end
     end
@@ -50,7 +50,7 @@ module ActiveRecord
     # Ensure, we can set connection params using the example of Generic
     # Query Optimizer (geqo). It is 'on' per default.
     def test_connection_options
-      params = ActiveRecord::Base.connection_config.dup
+      params = ActiveRecord::Base.connection_db_config.configuration_hash.dup
       params[:options] = "-c geqo=off"
       NonExistentTable.establish_connection(params)
 
@@ -234,10 +234,6 @@ module ActiveRecord
       end
     end
 
-    def test_supports_ranges_is_deprecated
-      assert_deprecated { @connection.supports_ranges? }
-    end
-
     private
       def with_warning_suppression
         log_level = @connection.client_min_messages
