@@ -25,9 +25,8 @@ class PostgresqlRenameTableTest < ActiveRecord::PostgreSQLTestCase
   end
 
   private
-
     def num_indices_named(name)
-      @connection.execute(<<-SQL).values.length
+      @connection.execute(<<~SQL).values.length
         SELECT 1 FROM "pg_index"
           JOIN "pg_class" ON "pg_index"."indexrelid" = "pg_class"."oid"
           WHERE "pg_class"."relname" = '#{name}'
