@@ -343,7 +343,11 @@ class InverseHasOneTests < ActiveRecord::TestCase
         Human.first.confused_face
       }
 
-      assert_match "Did you mean?", error.message
+      if error.respond_to?(:detailed_message)
+        assert_match "Did you mean?", error.detailed_message
+      else
+        assert_match "Did you mean?", error.message
+      end
       assert_equal "super_human", error.corrections.first
     end
   end
@@ -721,6 +725,15 @@ class InverseBelongsToTests < ActiveRecord::TestCase
     end
   end
 
+  def test_with_hash_many_inversing_does_not_add_duplicate_associated_objects
+    with_has_many_inversing do
+      human = Human.new
+      interest = Interest.new(human: human)
+      human.interests << interest
+      assert_equal 1, human.interests.size
+    end
+  end
+
   def test_unscope_does_not_set_inverse_when_incorrect
     interest = interests(:trainspotting)
     human = interest.human
@@ -761,7 +774,11 @@ class InverseBelongsToTests < ActiveRecord::TestCase
         Face.first.puzzled_human
       }
 
-      assert_match "Did you mean?", error.message
+      if error.respond_to?(:detailed_message)
+        assert_match "Did you mean?", error.detailed_message
+      else
+        assert_match "Did you mean?", error.message
+      end
       assert_equal "confused_face", error.corrections.first
     end
   end
