@@ -14,18 +14,16 @@ class TestDisconnectedAdapter < ActiveRecord::TestCase
 
   teardown do
     return if in_memory_db?
-    spec = ActiveRecord::Base.connection_config
-    ActiveRecord::Base.establish_connection(spec)
+    db_config = ActiveRecord::Base.connection_db_config
+    ActiveRecord::Base.establish_connection(db_config)
   end
 
   unless in_memory_db?
     test "can't execute statements while disconnected" do
       @connection.execute "SELECT count(*) from products"
       @connection.disconnect!
-      assert_raises(ActiveRecord::StatementInvalid) do
-        silence_warnings do
-          @connection.execute "SELECT count(*) from products"
-        end
+      assert_raises(ActiveRecord::ConnectionNotEstablished) do
+        @connection.execute "SELECT count(*) from products"
       end
     end
   end
