@@ -2,15 +2,24 @@
 
 require "cases/helper"
 require "models/post"
+require "models/author"
+require "models/human"
+require "models/essay"
 require "models/comment"
+require "models/categorization"
 
 module ActiveRecord
   class WhereChainTest < ActiveRecord::TestCase
-    fixtures :posts
+    fixtures :posts, :comments, :authors, :humans, :essays
 
-    def setup
-      super
-      @name = "title"
+    def test_missing_with_association
+      assert posts(:authorless).author.blank?
+      assert_equal [posts(:authorless)], Post.where.missing(:author).to_a
+    end
+
+    def test_missing_with_multiple_association
+      assert posts(:authorless).comments.empty?
+      assert_equal [posts(:authorless)], Post.where.missing(:author, :comments).to_a
     end
 
     def test_not_inverts_where_clause
@@ -27,7 +36,7 @@ module ActiveRecord
     end
 
     def test_association_not_eq
-      expected = Comment.arel_table[@name].not_eq(Arel::Nodes::BindParam.new(1))
+      expected = Comment.arel_table["title"].not_eq(Arel::Nodes::BindParam.new(1))
       relation = Post.joins(:comments).where.not(comments: { title: "hello" })
       assert_equal(expected.to_sql, relation.where_clause.ast.to_sql)
     end
@@ -60,48 +69,73 @@ module ActiveRecord
     end
 
     def test_rewhere_with_one_condition
-      relation = Post.where(title: "hello").where(title: "world").rewhere(title: "alone")
-      expected = Post.where(title: "alone")
+      relation = Post.where(body: "hello").where(body: "world").rewhere(body: "hullo")
+      expected = Post.where(body: "hullo")
 
-      assert_equal expected.where_clause, relation.where_clause
+      assert_equal expected.to_a, relation.to_a
     end
 
     def test_rewhere_with_multiple_overwriting_conditions
-      relation = Post.where(title: "hello").where(body: "world").rewhere(title: "alone", body: "again")
-      expected = Post.where(title: "alone", body: "again")
+      relation = Post.where(body: "hello").where(type: "StiPost").rewhere(body: "hullo", type: "Post")
+      expected = Post.where(body: "hullo", type: "Post")
 
-      assert_equal expected.where_clause, relation.where_clause
+      assert_equal expected.to_a, relation.to_a
     end
 
     def test_rewhere_with_one_overwriting_condition_and_one_unrelated
-      relation = Post.where(title: "hello").where(body: "world").rewhere(title: "alone")
-      expected = Post.where(body: "world", title: "alone")
+      relation = Post.where(body: "hello").where(type: "Post").rewhere(body: "hullo")
+      expected = Post.where(body: "hullo", type: "Post")
 
-      assert_equal expected.where_clause, relation.where_clause
+      assert_equal expected.to_a, relation.to_a
+    end
+
+    def test_rewhere_with_alias_condition
+      relation = Post.where(text: "hello").where(text: "world").rewhere(text: "hullo")
+      expected = Post.where(text: "hullo")
+
+      assert_equal expected.to_a, relation.to_a
+    end
+
+    def test_rewhere_with_nested_condition
+      relation = Post.where.missing(:comments).rewhere("comments.id": comments(:does_it_hurt))
+      expected = Post.left_joins(:comments).where("comments.id": comments(:does_it_hurt))
+
+      assert_equal expected.to_a, relation.to_a
+    end
+
+    def test_rewhere_with_polymorphic_association
+      relation = Essay.where(writer: authors(:david)).rewhere(writer: humans(:steve))
+      expected = Essay.where(writer: humans(:steve))
+
+      assert_equal expected.to_a, relation.to_a
     end
 
     def test_rewhere_with_range
       relation = Post.where(comments_count: 1..3).rewhere(comments_count: 3..5)
+      expected = Post.where(comments_count: 3..5)
 
-      assert_equal Post.where(comments_count: 3..5), relation
+      assert_equal expected.to_a, relation.to_a
     end
 
     def test_rewhere_with_infinite_upper_bound_range
       relation = Post.where(comments_count: 1..Float::INFINITY).rewhere(comments_count: 3..5)
+      expected = Post.where(comments_count: 3..5)
 
-      assert_equal Post.where(comments_count: 3..5), relation
+      assert_equal expected.to_a, relation.to_a
     end
 
     def test_rewhere_with_infinite_lower_bound_range
       relation = Post.where(comments_count: -Float::INFINITY..1).rewhere(comments_count: 3..5)
+      expected = Post.where(comments_count: 3..5)
 
-      assert_equal Post.where(comments_count: 3..5), relation
+      assert_equal expected.to_a, relation.to_a
     end
 
     def test_rewhere_with_infinite_range
       relation = Post.where(comments_count: -Float::INFINITY..Float::INFINITY).rewhere(comments_count: 3..5)
+      expected = Post.where(comments_count: 3..5)
 
-      assert_equal Post.where(comments_count: 3..5), relation
+      assert_equal expected.to_a, relation.to_a
     end
   end
 end
