@@ -1,5 +1,5 @@
 # frozen_string_literal: true
 
 class MixedCaseMonkey < ActiveRecord::Base
-  belongs_to :man
+  belongs_to :human
 end
