@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require "abstract_unit"
+require_relative "../abstract_unit"
 require "concurrent/atomic/count_down_latch"
 require "active_support/concurrency/load_interlock_aware_monitor"
 
