@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
-require "abstract_unit"
-require "multibyte_test_helpers"
+require_relative "abstract_unit"
+require_relative "multibyte_test_helpers"
 require "active_support/core_ext/string/multibyte"
 
 class MultibyteCharsTest < ActiveSupport::TestCase
@@ -72,18 +72,6 @@ class MultibyteCharsTest < ActiveSupport::TestCase
     assert_equal "abb", mb_a << mb_b
   end
 
-  def test_consumes_utf8_strings
-    ActiveSupport::Deprecation.silence do
-      assert @proxy_class.consumes?(UNICODE_STRING)
-      assert @proxy_class.consumes?(ASCII_STRING)
-      assert_not @proxy_class.consumes?(BYTE_STRING)
-    end
-  end
-
-  def test_consumes_is_deprecated
-    assert_deprecated { @proxy_class.consumes?(UNICODE_STRING) }
-  end
-
   def test_concatenation_should_return_a_proxy_class_instance
     assert_equal ActiveSupport::Multibyte.proxy_class, ("a".mb_chars + "b").class
     assert_equal ActiveSupport::Multibyte.proxy_class, ((+"a").mb_chars << "b").class
@@ -124,13 +112,13 @@ class MultibyteCharsUTF8BehaviourTest < ActiveSupport::TestCase
     class_eval(<<-EOTESTS, __FILE__, __LINE__ + 1)
       def test_#{method}_bang_should_return_self_when_modifying_wrapped_string
         chars = ' él piDió Un bUen café '.dup
-        assert_equal chars.object_id, chars.send("#{method}!").object_id
+        assert_equal chars.object_id, chars.public_send("#{method}!").object_id
       end
 
       def test_#{method}_bang_should_change_wrapped_string
         original = ' él piDió Un bUen café '.dup
         proxy = chars(original.dup)
-        proxy.send("#{method}!")
+        proxy.public_send("#{method}!")
         assert_not_equal original, proxy.to_s
       end
     EOTESTS
@@ -171,9 +159,6 @@ class MultibyteCharsUTF8BehaviourTest < ActiveSupport::TestCase
     assert chars("").upcase.kind_of?(ActiveSupport::Multibyte.proxy_class)
     assert chars("").downcase.kind_of?(ActiveSupport::Multibyte.proxy_class)
     assert chars("").capitalize.kind_of?(ActiveSupport::Multibyte.proxy_class)
-    ActiveSupport::Deprecation.silence do
-      assert chars("").normalize.kind_of?(ActiveSupport::Multibyte.proxy_class)
-    end
     assert chars("").decompose.kind_of?(ActiveSupport::Multibyte.proxy_class)
     assert chars("").compose.kind_of?(ActiveSupport::Multibyte.proxy_class)
     assert chars("").tidy_bytes.kind_of?(ActiveSupport::Multibyte.proxy_class)
@@ -204,6 +189,12 @@ class MultibyteCharsUTF8BehaviourTest < ActiveSupport::TestCase
     assert_equal 3, (@chars =~ /わ/u)
   end
 
+  def test_match_should_return_boolean_for_regexp_match
+    assert_not @chars.match?(/wrong/u)
+    assert @chars.match?(/こに/u)
+    assert @chars.match?(/ち/u)
+  end
+
   def test_should_use_character_offsets_for_insert_offsets
     assert_equal "", (+"").mb_chars.insert(0, "")
     assert_equal "こわにちわ", @chars.insert(1, "わ")
@@ -391,12 +382,6 @@ class MultibyteCharsUTF8BehaviourTest < ActiveSupport::TestCase
   def test_reverse_should_work_with_normalized_strings
     str = "bös"
     reversed_str = "söb"
-    ActiveSupport::Deprecation.silence do
-      assert_equal chars(reversed_str).normalize(:kc), chars(str).normalize(:kc).reverse
-      assert_equal chars(reversed_str).normalize(:c), chars(str).normalize(:c).reverse
-      assert_equal chars(reversed_str).normalize(:d), chars(str).normalize(:d).reverse
-      assert_equal chars(reversed_str).normalize(:kd), chars(str).normalize(:kd).reverse
-    end
     assert_equal chars(reversed_str).decompose, chars(str).decompose.reverse
     assert_equal chars(reversed_str).compose, chars(str).compose.reverse
   end
@@ -575,57 +560,13 @@ class MultibyteCharsExtrasTest < ActiveSupport::TestCase
     end
   end
 
-  def test_composition_exclusion_is_set_up_properly
-    # Normalization of DEVANAGARI LETTER QA breaks when composition exclusion isn't used correctly
-    qa = [0x915, 0x93c].pack("U*")
-    ActiveSupport::Deprecation.silence do
-      assert_equal qa, chars(qa).normalize(:c)
-    end
-  end
-
-  # Test for the Public Review Issue #29, bad explanation of composition might lead to a
-  # bad implementation: http://www.unicode.org/review/pr-29.html
-  def test_normalization_C_pri_29
-    [
-      [0x0B47, 0x0300, 0x0B3E],
-      [0x1100, 0x0300, 0x1161]
-    ].map { |c| c.pack("U*") }.each do |c|
-      ActiveSupport::Deprecation.silence do
-        assert_equal_codepoints c, chars(c).normalize(:c)
-      end
-    end
-  end
-
   def test_normalization_shouldnt_strip_null_bytes
     null_byte_str = "Test\0test"
 
-    ActiveSupport::Deprecation.silence do
-      assert_equal null_byte_str, chars(null_byte_str).normalize(:kc)
-      assert_equal null_byte_str, chars(null_byte_str).normalize(:c)
-      assert_equal null_byte_str, chars(null_byte_str).normalize(:d)
-      assert_equal null_byte_str, chars(null_byte_str).normalize(:kd)
-    end
     assert_equal null_byte_str, chars(null_byte_str).decompose
     assert_equal null_byte_str, chars(null_byte_str).compose
   end
 
-  def test_simple_normalization
-    comp_str = [
-      44,  # LATIN CAPITAL LETTER D
-      307, # COMBINING DOT ABOVE
-      328, # COMBINING OGONEK
-      323 # COMBINING DOT BELOW
-    ].pack("U*")
-
-    ActiveSupport::Deprecation.silence do
-      assert_equal_codepoints "", chars("").normalize
-      assert_equal_codepoints [44, 105, 106, 328, 323].pack("U*"), chars(comp_str).normalize(:kc).to_s
-      assert_equal_codepoints [44, 307, 328, 323].pack("U*"), chars(comp_str).normalize(:c).to_s
-      assert_equal_codepoints [44, 307, 110, 780, 78, 769].pack("U*"), chars(comp_str).normalize(:d).to_s
-      assert_equal_codepoints [44, 105, 106, 110, 780, 78, 769].pack("U*"), chars(comp_str).normalize(:kd).to_s
-    end
-  end
-
   def test_should_compute_grapheme_length
     [
       ["", 0],
@@ -737,51 +678,6 @@ class MultibyteCharsExtrasTest < ActiveSupport::TestCase
     assert_equal BYTE_STRING.dup.mb_chars.class, ActiveSupport::Multibyte::Chars
   end
 
-  def test_unicode_normalize_deprecation
-    # String#unicode_normalize default form is `:nfc`, and
-    # different than Multibyte::Unicode default, `:nkfc`.
-    # Deprecation should suggest the right form if no params
-    # are given and default is used.
-    assert_deprecated(/unicode_normalize\(:nfkc\)/) do
-      ActiveSupport::Multibyte::Unicode.normalize("")
-    end
-
-    assert_deprecated(/unicode_normalize\(:nfd\)/) do
-      ActiveSupport::Multibyte::Unicode.normalize("", :d)
-    end
-  end
-
-  def test_chars_normalize_deprecation
-    # String#unicode_normalize default form is `:nfc`, and
-    # different than Multibyte::Unicode default, `:nkfc`.
-    # Deprecation should suggest the right form if no params
-    # are given and default is used.
-    assert_deprecated(/unicode_normalize\(:nfkc\)/) do
-      "".mb_chars.normalize
-    end
-
-    assert_deprecated(/unicode_normalize\(:nfc\)/) { "".mb_chars.normalize(:c) }
-    assert_deprecated(/unicode_normalize\(:nfd\)/) { "".mb_chars.normalize(:d) }
-    assert_deprecated(/unicode_normalize\(:nfkc\)/) { "".mb_chars.normalize(:kc) }
-    assert_deprecated(/unicode_normalize\(:nfkd\)/) { "".mb_chars.normalize(:kd) }
-  end
-
-  def test_unicode_deprecations
-    assert_deprecated { ActiveSupport::Multibyte::Unicode.downcase("") }
-    assert_deprecated { ActiveSupport::Multibyte::Unicode.upcase("") }
-    assert_deprecated { ActiveSupport::Multibyte::Unicode.swapcase("") }
-  end
-
-  def test_normalize_non_unicode_string
-    # Fullwidth Latin Capital Letter A in Windows 31J
-    str = "\u{ff21}".encode(Encoding::Windows_31J)
-    assert_raise Encoding::CompatibilityError do
-      ActiveSupport::Deprecation.silence do
-        ActiveSupport::Multibyte::Unicode.normalize(str)
-      end
-    end
-  end
-
   private
     def string_from_classes(classes)
       # Characters from the character classes as described in UAX #29
