@@ -10,8 +10,13 @@ module Rails
         class ChangeCommand < Base # :nodoc:
           class_option :to, desc: "The database system to switch to."
 
+          def initialize(positional_args, option_args, *)
+            @argv = positional_args + option_args
+            super
+          end
+
           def perform
-            Rails::Generators::Db::System::ChangeGenerator.start
+            Rails::Generators::Db::System::ChangeGenerator.start(@argv)
           end
         end
       end
