@@ -7,10 +7,10 @@ module Rails
   end
 
   module VERSION
-    MAJOR = 5
-    MINOR = 2
-    TINY  = 3
-    PRE   = nil
+    MAJOR = 6
+    MINOR = 1
+    TINY  = 7
+    PRE   = "3"
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
