@@ -47,7 +47,7 @@ module Rails
         # Started GET "/session/new" for 127.0.0.1 at 2012-09-26 14:51:42 -0700
         def started_request_message(request) # :doc:
           'Started %s "%s" for %s at %s' % [
-            request.request_method,
+            request.raw_request_method,
             request.filtered_path,
             request.remote_ip,
             Time.now.to_default_s ]
