@@ -29,7 +29,7 @@ module ApplicationTests
       simple_controller
 
       get "/"
-      assert !last_response.headers["X-Sendfile"]
+      assert_not last_response.headers["X-Sendfile"]
       assert_equal File.read(__FILE__), last_response.body
     end
 
