@@ -23,7 +23,7 @@ module ApplicationTests
 
       File.open("#{app_path}/config/boot.rb", "w") do |f|
         f.puts "ENV['BUNDLE_GEMFILE'] = '#{Bundler.default_gemfile}'"
-        f.puts "require 'bundler/setup'"
+        f.puts 'require "bundler/setup"'
       end
 
       primary, replica = PTY.open
@@ -42,6 +42,32 @@ module ApplicationTests
       end
     end
 
+    test "run +server+ blocks after the server starts" do
+      skip "PTY unavailable" unless available_pty?
+
+      File.open("#{app_path}/config/boot.rb", "w") do |f|
+        f.puts "ENV['BUNDLE_GEMFILE'] = '#{Bundler.default_gemfile}'"
+        f.puts 'require "bundler/setup"'
+      end
+
+      add_to_config(<<~CODE)
+        server do
+          puts 'Hello world'
+        end
+      CODE
+
+      primary, replica = PTY.open
+      pid = nil
+
+      Bundler.with_original_env do
+        pid = Process.spawn("bin/rails server -b localhost", chdir: app_path, in: replica, out: primary, err: replica)
+        assert_output("Hello world", primary)
+        assert_output("Listening", primary)
+      ensure
+        kill(pid) if pid
+      end
+    end
+
     private
       def kill(pid)
         Process.kill("TERM", pid)
