@@ -71,16 +71,26 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "test/test_helper.rb" do |content|
       assert_match(/require_relative.+test\/dummy\/config\/environment/, content)
       assert_match(/ActiveRecord::Migrator\.migrations_paths.+test\/dummy\/db\/migrate/, content)
-      assert_match(/Minitest\.backtrace_filter = Minitest::BacktraceFilter\.new/, content)
       assert_match(/Rails::TestUnitReporter\.executable = 'bin\/test'/, content)
     end
     assert_file "lib/bukkits/railtie.rb", /module Bukkits\n  class Railtie < ::Rails::Railtie\n  end\nend/
-    assert_file "lib/bukkits.rb", /require "bukkits\/railtie"/
-    assert_file "test/bukkits_test.rb", /assert_kind_of Module, Bukkits/
+    assert_file "lib/bukkits.rb" do |content|
+      assert_match(/require "bukkits\/version"/, content)
+      assert_match(/require "bukkits\/railtie"/, content)
+    end
+    assert_file "test/bukkits_test.rb" do |content|
+      assert_match(/class BukkitsTest < ActiveSupport::TestCase/, content)
+      assert_match(/assert Bukkits::VERSION/, content)
+    end
     assert_file "bin/test"
     assert_no_file "bin/rails"
   end
 
+  def test_initializes_git_repo
+    run_generator
+    assert_directory ".git"
+  end
+
   def test_generating_in_full_mode_with_almost_of_all_skip_options
     run_generator [destination_root, "--full", "-M", "-O", "-C", "-S", "-T", "--skip-active-storage"]
     assert_file "bin/rails" do |content|
@@ -154,23 +164,31 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_no_directory "test"
   end
 
-  def test_database_entry_is_generated_for_sqlite3_by_default_in_full_mode
-    run_generator([destination_root, "--full"])
-    assert_file "test/dummy/config/database.yml", /sqlite/
-    assert_file "bukkits.gemspec", /sqlite3/
-  end
-
-  def test_config_another_database
-    run_generator([destination_root, "-d", "mysql", "--full"])
-    assert_file "test/dummy/config/database.yml", /mysql/
-    assert_file "bukkits.gemspec", /mysql/
-  end
-
-  def test_dont_generate_development_dependency
-    run_generator [destination_root, "--skip-active-record"]
-
+  def test_no_development_dependencies_in_gemspec
+    run_generator
     assert_file "bukkits.gemspec" do |contents|
-      assert_no_match(/s\.add_development_dependency "sqlite3"/, contents)
+      assert_no_match(/add_development_dependency/, contents)
+    end
+  end
+
+  def test_default_database_dependency_is_sqlite
+    run_generator
+    assert_file "test/dummy/config/database.yml", /sqlite/
+    assert_file "Gemfile" do |contents|
+      assert_match_sqlite3(contents)
+    end
+  end
+
+  def test_custom_database_dependency
+    run_generator [destination_root, "-d", "mysql"]
+    assert_file "test/dummy/config/database.yml", /mysql/
+    assert_file "Gemfile", /mysql/
+  end
+
+  def test_skip_database_dependency
+    run_generator [destination_root, "--skip-active-record"]
+    assert_file "Gemfile" do |contents|
+      assert_no_match(/sqlite/, contents)
     end
   end
 
@@ -198,7 +216,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
 
   def test_edge_option
     assert_generates_without_bundler(edge: true)
-    assert_file "Gemfile", %r{^gem\s+["']rails["'],\s+github:\s+["']#{Regexp.escape("rails/rails")}["'],\s+branch:\s+["']#{Regexp.escape("6-0-stable")}["']$}
+    assert_file "Gemfile", %r{^gem\s+["']rails["'],\s+github:\s+["']#{Regexp.escape("rails/rails")}["'],\s+branch:\s+["']#{Regexp.escape("6-1-stable")}["']$}
   end
 
   def test_generation_does_not_run_bundle_install_with_full_and_mountable
@@ -213,6 +231,24 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     end
   end
 
+  def test_skip_action_mailer_and_skip_active_job_with_mountable
+    run_generator [destination_root, "--mountable", "--skip-action-mailer", "--skip-active-job"]
+    assert_no_directory "app/mailers"
+    assert_no_directory "app/jobs"
+  end
+
+  def test_skip_action_mailer_and_skip_active_job_with_api_and_mountable
+    run_generator [destination_root, "--api", "--mountable", "--skip-action-mailer", "--skip-active-job"]
+    assert_no_directory "app/mailers"
+    assert_no_directory "app/jobs"
+  end
+
+  def test_skip_action_mailer_and_skip_active_job_with_full
+    run_generator [destination_root, "--full", "--skip-action-mailer", "--skip-active-job"]
+    assert_no_directory "app/mailers"
+    assert_no_directory "app/jobs"
+  end
+
   def test_template_from_dir_pwd
     FileUtils.cd(Rails.root)
     assert_match(/It works from file!/, run_generator([destination_root, "-m", "lib/template.rb"]))
@@ -249,6 +285,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "app/views"
     assert_file "app/helpers"
     assert_file "app/mailers"
+    assert_file "app/jobs"
     assert_file "bin/rails", /\s+require\s+["']rails\/all["']/
     assert_file "config/routes.rb", /Rails.application.routes.draw do/
     assert_file "lib/bukkits/engine.rb", /module Bukkits\n  class Engine < ::Rails::Engine\n  end\nend/
@@ -265,6 +302,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "hyphenated-name/app/views"
     assert_file "hyphenated-name/app/helpers"
     assert_file "hyphenated-name/app/mailers"
+    assert_file "hyphenated-name/app/jobs"
     assert_file "hyphenated-name/bin/rails"
     assert_file "hyphenated-name/config/routes.rb",              /Rails.application.routes.draw do/
     assert_file "hyphenated-name/lib/hyphenated/name/engine.rb", /module Hyphenated\n  module Name\n    class Engine < ::Rails::Engine\n    end\n  end\nend/
@@ -282,6 +320,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "my_hyphenated-name/app/views"
     assert_file "my_hyphenated-name/app/helpers"
     assert_file "my_hyphenated-name/app/mailers"
+    assert_file "my_hyphenated-name/app/jobs"
     assert_file "my_hyphenated-name/bin/rails"
     assert_file "my_hyphenated-name/config/routes.rb",              /Rails\.application\.routes\.draw do/
     assert_file "my_hyphenated-name/lib/my_hyphenated/name/engine.rb", /module MyHyphenated\n  module Name\n    class Engine < ::Rails::Engine\n    end\n  end\nend/
@@ -333,7 +372,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "hyphenated-name/lib/hyphenated/name/engine.rb",                             /module Hyphenated\n  module Name\n    class Engine < ::Rails::Engine\n      isolate_namespace Hyphenated::Name\n    end\n  end\nend/
     assert_file "hyphenated-name/lib/hyphenated/name.rb",                                    /require "hyphenated\/name\/engine"/
     assert_file "hyphenated-name/test/dummy/config/routes.rb",                               /mount Hyphenated::Name::Engine => "\/hyphenated-name"/
-    assert_file "hyphenated-name/app/controllers/hyphenated/name/application_controller.rb", /module Hyphenated\n  module Name\n    class ApplicationController < ActionController::Base\n      protect_from_forgery with: :exception\n    end\n  end\nend\n/
+    assert_file "hyphenated-name/app/controllers/hyphenated/name/application_controller.rb", /module Hyphenated\n  module Name\n    class ApplicationController < ActionController::Base\n    end\n  end\nend\n/
     assert_file "hyphenated-name/app/models/hyphenated/name/application_record.rb",          /module Hyphenated\n  module Name\n    class ApplicationRecord < ActiveRecord::Base\n      self\.abstract_class = true\n    end\n  end\nend/
     assert_file "hyphenated-name/app/jobs/hyphenated/name/application_job.rb",               /module Hyphenated\n  module Name\n    class ApplicationJob < ActiveJob::Base/
     assert_file "hyphenated-name/app/mailers/hyphenated/name/application_mailer.rb",         /module Hyphenated\n  module Name\n    class ApplicationMailer < ActionMailer::Base\n      default from: 'from@example\.com'\n      layout 'mailer'\n    end\n  end\nend/
@@ -355,7 +394,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "my_hyphenated-name/lib/my_hyphenated/name/engine.rb",                             /module MyHyphenated\n  module Name\n    class Engine < ::Rails::Engine\n      isolate_namespace MyHyphenated::Name\n    end\n  end\nend/
     assert_file "my_hyphenated-name/lib/my_hyphenated/name.rb",                                    /require "my_hyphenated\/name\/engine"/
     assert_file "my_hyphenated-name/test/dummy/config/routes.rb",                                  /mount MyHyphenated::Name::Engine => "\/my_hyphenated-name"/
-    assert_file "my_hyphenated-name/app/controllers/my_hyphenated/name/application_controller.rb", /module MyHyphenated\n  module Name\n    class ApplicationController < ActionController::Base\n      protect_from_forgery with: :exception\n    end\n  end\nend\n/
+    assert_file "my_hyphenated-name/app/controllers/my_hyphenated/name/application_controller.rb", /module MyHyphenated\n  module Name\n    class ApplicationController < ActionController::Base\n    end\n  end\nend\n/
     assert_file "my_hyphenated-name/app/models/my_hyphenated/name/application_record.rb",          /module MyHyphenated\n  module Name\n    class ApplicationRecord < ActiveRecord::Base\n      self\.abstract_class = true\n    end\n  end\nend/
     assert_file "my_hyphenated-name/app/jobs/my_hyphenated/name/application_job.rb",               /module MyHyphenated\n  module Name\n    class ApplicationJob < ActiveJob::Base/
     assert_file "my_hyphenated-name/app/mailers/my_hyphenated/name/application_mailer.rb",         /module MyHyphenated\n  module Name\n    class ApplicationMailer < ActionMailer::Base\n      default from: 'from@example\.com'\n      layout 'mailer'\n    end\n  end\nend/
@@ -377,7 +416,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "deep-hyphenated-name/lib/deep/hyphenated/name/engine.rb",                             /module Deep\n  module Hyphenated\n    module Name\n      class Engine < ::Rails::Engine\n        isolate_namespace Deep::Hyphenated::Name\n      end\n    end\n  end\nend/
     assert_file "deep-hyphenated-name/lib/deep/hyphenated/name.rb",                                    /require "deep\/hyphenated\/name\/engine"/
     assert_file "deep-hyphenated-name/test/dummy/config/routes.rb",                                    /mount Deep::Hyphenated::Name::Engine => "\/deep-hyphenated-name"/
-    assert_file "deep-hyphenated-name/app/controllers/deep/hyphenated/name/application_controller.rb", /module Deep\n  module Hyphenated\n    module Name\n      class ApplicationController < ActionController::Base\n        protect_from_forgery with: :exception\n      end\n    end\n  end\nend\n/
+    assert_file "deep-hyphenated-name/app/controllers/deep/hyphenated/name/application_controller.rb", /module Deep\n  module Hyphenated\n    module Name\n      class ApplicationController < ActionController::Base\n      end\n    end\n  end\nend\n/
     assert_file "deep-hyphenated-name/app/models/deep/hyphenated/name/application_record.rb",          /module Deep\n  module Hyphenated\n    module Name\n      class ApplicationRecord < ActiveRecord::Base\n        self\.abstract_class = true\n      end\n    end\n  end\nend/
     assert_file "deep-hyphenated-name/app/jobs/deep/hyphenated/name/application_job.rb",               /module Deep\n  module Hyphenated\n    module Name\n      class ApplicationJob < ActiveJob::Base/
     assert_file "deep-hyphenated-name/app/mailers/deep/hyphenated/name/application_mailer.rb",         /module Deep\n  module Hyphenated\n    module Name\n      class ApplicationMailer < ActionMailer::Base\n        default from: 'from@example\.com'\n        layout 'mailer'\n      end\n    end\n  end\nend/
@@ -401,8 +440,8 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "bin/rails", /ENGINE_PATH = File\.expand_path\('\.\.\/lib\/bukkits\/engine', __dir__\)/
     assert_file "bin/rails", /ENGINE_ROOT = File\.expand_path\('\.\.', __dir__\)/
     assert_file "bin/rails", %r|APP_PATH = File\.expand_path\('\.\./test/dummy/config/application', __dir__\)|
-    assert_file "bin/rails", /require 'rails\/all'/
-    assert_file "bin/rails", /require 'rails\/engine\/commands'/
+    assert_file "bin/rails", /require "rails\/all"/
+    assert_file "bin/rails", /require "rails\/engine\/commands"/
   end
 
   def test_shebang
@@ -442,6 +481,20 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     end
   end
 
+  def test_dummy_application_loads_plugin
+    run_generator
+
+    assert_file "test/dummy/config/application.rb", /^require "bukkits"/
+  end
+
+  def test_dummy_application_uses_dynamic_rails_version_number
+    run_generator
+
+    assert_file "test/dummy/config/application.rb" do |contents|
+      assert_match(/^\s*config\.load_defaults Rails::VERSION::STRING\.to_f/, contents)
+    end
+  end
+
   def test_dummy_application_skip_listen_by_default
     run_generator
 
@@ -461,6 +514,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
   def test_unnecessary_files_are_not_generated_in_dummy_application
     run_generator
     assert_no_file "test/dummy/.gitignore"
+    assert_no_file "test/dummy/.ruby-version"
     assert_no_file "test/dummy/db/seeds.rb"
     assert_no_file "test/dummy/Gemfile"
     assert_no_file "test/dummy/public/robots.txt"
@@ -473,6 +527,14 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_no_directory "test/dummy/.git"
   end
 
+  def test_spring_binstub_is_not_generated_in_dummy_application
+    run_generator
+    assert_no_file "test/dummy/bin/spring"
+    assert_file "test/dummy/bin/rails" do |contents|
+      assert_no_match %r/spring/, contents
+    end
+  end
+
   def test_skipping_test_files
     run_generator [destination_root, "--skip-test"]
     assert_no_directory "test"
@@ -487,7 +549,6 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "Gemfile" do |contents|
       assert_no_match("gemspec", contents)
       assert_match(/gem 'rails'/, contents)
-      assert_match_sqlite3(contents)
     end
   end
 
@@ -497,7 +558,6 @@ class PluginGeneratorTest < Rails::Generators::TestCase
     assert_file "Gemfile" do |contents|
       assert_no_match("gemspec", contents)
       assert_match(/gem 'rails'/, contents)
-      assert_match_sqlite3(contents)
     end
   end
 
@@ -592,6 +652,7 @@ class PluginGeneratorTest < Rails::Generators::TestCase
       assert_match name, contents
       assert_match email, contents
     end
+    assert_no_directory ".git"
   end
 
   def test_skipping_useless_folders_generation_for_api_engines
@@ -733,11 +794,8 @@ class PluginGeneratorTest < Rails::Generators::TestCase
       generator([destination_root], options)
 
       command_check = -> command do
-        case command
-        when "install"
-          flunk "install expected to not be called"
-        when "exec spring binstub --all"
-          # Called when running tests with spring, let through unscathed.
+        if command == "install"
+          flunk "`install` expected to not be called."
         end
       end
 
